@@ -109,16 +109,18 @@ def get_distro_name():
 class Password(object):
     def __init__(self, Mode = INTERACTIVE_MODE):
         self.__password =""
+        self.__password_prompt_str=""
         self.__passwordValidated = False
         self.__mode = Mode
         self.__readAuthType()  #self.__authType   
         self.__expectList =[]
 
-        if not utils.to_bool(sys_conf.get('configure','qt4', '0')) and utils.to_bool(sys_conf.get('configure','qt3', '0')):
+        if not utils.to_bool(sys_conf.get('configure','qt5', '0')) and not not utils.to_bool(sys_conf.get('configure','qt4', '0')) and utils.to_bool(sys_conf.get('configure','qt3', '0')):
             self.__ui_toolkit = 'qt3'
-        else:
+        elif not utils.to_bool(sys_conf.get('configure','qt5', '0')) and not utils.to_bool(sys_conf.get('configure','qt3', '0')) and utils.to_bool(sys_conf.get('configure','qt4', '0')):
             self.__ui_toolkit = 'qt4'
-            
+        elif not utils.to_bool(sys_conf.get('configure','qt3', '0')) and not utils.to_bool(sys_conf.get('configure','qt4', '0')) and utils.to_bool(sys_conf.get('configure','qt5', '0')):
+            self.__ui_toolkit = 'qt5'
             
         for s in utils.EXPECT_WORD_LIST:
             try:
@@ -175,6 +177,9 @@ class Password(object):
         if self.__ui_toolkit == "qt3":
             from ui.setupform import showPasswordUI
             username, password = showPasswordUI(pswd_msg, user, False)
+        elif self.__ui_toolkit == "qt5":
+            from ui5.setupdialog import showPasswordUI
+            username, password = showPasswordUI(pswd_msg, user, False)
         else:       #self.__ui_toolkit == "qt4" --> default qt4
             from ui4.setupdialog import showPasswordUI
             username, password = showPasswordUI(pswd_msg, user, False)
@@ -205,8 +210,7 @@ class Password(object):
                     i = child.expect(self.__expectList)
                     
                     cb = child.before
-                    if cb:
-
+                    if cb:  
                         start = time.time()
                         output.write(cb)
 
@@ -214,11 +218,26 @@ class Password(object):
                         ok, ret = True, output.getvalue()
                         break
 
-                    elif i == 1: # TIMEOUT
-                        
+                    elif i == 1: # TIMEOUT                        
+                        if('true' in cmd and self.__password_prompt_str == ""): #sudo true or su -c "true"
+                            cb = cb.replace("[", "\[")
+                            cb = cb.replace("]", "\]")
+
+                            self.__password_prompt_str = cb
+                            try:
+                                p = re.compile(cb, re.I)
+                            except TypeError:
+                                self.__expectList.append(cb)
+                            else:
+                                self.__expectList.append(p)
+                            log.debug("Adding missing password prompt string [%s]"%self.__password_prompt_str)
                         continue
 
                     else: # password
+                        if(self.__password_prompt_str == ""): 
+                            self.__password_prompt_str = utils.EXPECT_WORD_LIST[i]
+                            log.debug("Updating password prompt string [%s]"%self.__password_prompt_str)
+
                         child.sendline(self.__password)
 
             except (Exception, pexpect.ExceptionPexpect) as e:          
@@ -245,10 +264,14 @@ class Password(object):
             if self.__mode == INTERACTIVE_MODE:
                 self.__password = self.__get_password(pswd_msg)
             else:
-                if self.getAuthType() == 'su':
-                    self.__password = self.__get_password_ui(pswd_msg, "root")
-                else:
-                    self.__password = self.__get_password_ui(pswd_msg, os.getenv("USER"))
+                try:
+                    if self.getAuthType() == 'su':
+                        self.__password = self.__get_password_ui(pswd_msg, "root")
+                    else:
+                        self.__password = self.__get_password_ui(pswd_msg, os.getenv("USER"))
+                except Exception as ex:
+                    log.debug(ex)
+                    break
 
             cmd = self.getAuthCmd() % "true"
             log.debug(cmd)
@@ -259,7 +282,9 @@ class Password(object):
             if self.__mode == GUI_MODE:
                 if self.__ui_toolkit == "qt4":
                     from ui4.setupdialog import FailureMessageUI
-                if self.__ui_toolkit == "qt3":
+                elif self.__ui_toolkit == "qt5":
+                    from ui5.setupdialog import FailureMessageUI
+                elif self.__ui_toolkit == "qt3":
                     from ui.setupform import FailureMessageUI
 
 
@@ -360,3 +385,7 @@ class Password(object):
         self.__validatePassword( pswd_msg)
         return self.__password
 
+    def getPasswordPromptString(self):
+        return self.__password_prompt_str
+
+
